package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: May 21, 2017
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
EarthRadius is the radium of the earth in meters
ToRadians converts a number in degrees to radians
type Point struct {
Latitude float64 `json:"lat"`
Longitude float64 `json:"lon"`
}
Point represents a point on earth
Lerp Linear interpolation between two points for a parameter t
DistanceTo target from point (meters)
Unwrap returns the latitude and longitude of a Coordinates struct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.